CMBLensed — pysm v3.1.dev260

pysm:docs

- Index
- Modules

### Navigation

- next »
- « previous |
- pysm v3.1.dev260 »
- CMBLensed

# CMBLensed

class `pysm.` `CMBLensed`(nside, cmb_spectra, cmb_seed=None, apply_delens=False, delensing_ells=None, map_dist=None)

  Bases: `pysm.CMBMap`

  Lensed CMB

  Takes an input unlensed CMB and lensing spectrum from CAMB and uses Taylens to apply lensing, it optionally simulates delensing by suppressing the lensing power at specific scales with the user provided `delensing_ells`.

  Parameters
    cmb_spectrapath

      Input text file from CAMB, spectra unlensed

    cmb_seedint

      Numpy random seed for synfast, set to None for a random seed

    apply_delensbool

      If true, simulate delensing with taylens

    delensing_ellspath

      Space delimited file with ells in the first columns and suppression factor (1 for no suppression) in the second column

  Methods Summary

  `run_taylens`(self) | Returns CMB (T, Q, U) maps as a function of observing frequency, nu.

  Methods Documentation

  `run_taylens`(self)

    Returns CMB (T, Q, U) maps as a function of observing frequency, nu.

    This code is extracted from the taylens code (reference).

    Returns

      function – CMB maps.